#
# Conditional build:
%bcond_without	doc	# PDF documentation
%bcond_without	python2 # CPython 2.x module
%bcond_with	python3 # CPython 3.x module (built from python3-reportlab.spec)

# TODO:
# - use system fonts (see files lists) or share fonts for both python versions
# - tools/docco and tools/pythonpoint as subpackages?

%define		module	ReportLab
Summary:	Python 2 library for generating PDFs and graphics
Summary(pl.UTF-8):	Moduły Pythona 2 do generowania PDF-ów oraz grafik
Name:		python-%{module}
# keep 3.5.x (or <=3.6.1?) here for python2 support
Version:	3.5.68
Release:	9
License:	BSD-like
Group:		Libraries/Python
#Source0Download: https://bitbucket.org/rptlab/reportlab/downloads/?tab=tags
Source0:	https://files.pythonhosted.org/packages/source/r/reportlab/reportlab-%{version}.tar.gz
# Source0-md5:	92f79d609974ae8d6c57d0e3187db297
Patch0:		reportlab-types.patch
URL:		https://www.reportlab.com/dev/opensource/
BuildRequires:	freetype-devel >= 2
BuildRequires:	libart_lgpl-devel >= 2
%if %{with python2}
BuildRequires:	python-devel >= 1:2.7
BuildRequires:	python-setuptools
%endif
%{?with_doc:BuildRequires:	python-pillow >= 4.0.0}
%if %{with python3}
BuildRequires:	python3-devel >= 1:3.6
BuildRequires:	python3-setuptools
%endif
BuildRequires:	rpm-pythonprov
BuildRequires:	rpmbuild(macros) >= 1.714
BuildRequires:	unzip
Requires:	python-modules >= 1:2.7
Obsoletes:	python-ReportLab-barcode < 1
Obsoletes:	python-ReportLab-renderPM < 2
Obsoletes:	python-ReportLab-rl_accel < 1
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
A library written in Python that lets you generate platform
independant PDFs and graphics.
- PDF generation: uses Python, a clean OO language, layered
  architecture
- Graphics: provides primitive shapes, reusable widgets, sample
  collections including business chart and diagrams

%description -l pl.UTF-8
Biblioteka napisana w Pythonie pozwalająca na generowanie niezależnych
od platformy PDF-ów oraz grafik.
- Generowanie PDF: używa Pythona, przejrzystego języka obiektowego o
  warstwowej architekturze
- Grafika: podstawowe figury geometryczne, kontrolki, a także
  przykłady, w tym wykresy i diagramy

%package -n python3-%{module}
Summary:	Python 3 library for generating PDFs and graphics
Summary(pl.UTF-8):	Moduły Pythona 3 do generowania PDF-ów oraz grafik
Group:		Libraries/Python
Requires:	python3-modules >= 1:3.6

%description -n python3-%{module}
A library written in Python that lets you generate platform
independant PDFs and graphics.
- PDF generation: uses Python, a clean OO language, layered
  architecture
- Graphics: provides primitive shapes, reusable widgets, sample
  collections including business chart and diagrams

%description -n python3-%{module} -l pl.UTF-8
Biblioteka napisana w Pythonie pozwalająca na generowanie niezależnych
od platformy PDF-ów oraz grafik.
- Generowanie PDF: używa Pythona, przejrzystego języka obiektowego o
  warstwowej architekturze
- Grafika: podstawowe figury geometryczne, kontrolki, a także
  przykłady, w tym wykresy i diagramy

%package apidocs
Summary:	API documentation for ReportLab module
Summary(pl.UTF_8):	Dokumentacja API modułu ReportLab
Group:		Documentation
BuildArch:	noarch

%description apidocs
API documentation for ReportLab module.

%description apidocs -l pl.UTF-8
Dokumentacja API modułu ReportLab.

%package examples
Summary:	Examples for ReportLab
Summary(pl.UTF-8):	Przykłady do biblioteki ReportLab
Group:		Libraries/Python
Requires:	%{name} = %{version}-%{release}
BuildArch:	noarch

%description examples
Examples for ReportLab.

%description examples -l pl.UTF-8
Przykłady do biblioteki ReportLab.

%prep
%setup -q -n reportlab-%{version}
%patch -P0 -p1

%build
%if %{with python2}
%py_build
%endif

%if %{with python3}
%py3_build
%endif

%if %{with doc}
cd docs
PYTHONPATH=$(echo $(pwd)/../build-2/lib.*) \
%{__python} genAll.py
cd ..
%endif

%install
rm -rf $RPM_BUILD_ROOT

%if %{with python2}
%py_install

install -d $RPM_BUILD_ROOT%{py_sitescriptdir}/reportlab

%py_postclean
%{__rm} -r $RPM_BUILD_ROOT%{py_sitedir}/reportlab/graphics/samples
%endif

%if %{with python3}
%py3_install

install -d $RPM_BUILD_ROOT%{py3_sitescriptdir}/reportlab

%{__rm} -r $RPM_BUILD_ROOT%{py3_sitedir}/reportlab/graphics/samples
%endif

install -d $RPM_BUILD_ROOT%{_examplesdir}/%{name}-%{version}
cp -a demos $RPM_BUILD_ROOT%{_examplesdir}/%{name}-%{version}

# TODO: (whole) pythonpoint as subpackage?
#install -p tools/pythonpoint/pythonpoint.py $RPM_BUILD_ROOT%{_bindir}
#cp -a tools/pythonpoint/demos $RPM_BUILD_ROOT%{_examplesdir}/%{name}-%{version}/pythonpoint-demos

%clean
rm -rf $RPM_BUILD_ROOT

%if %{with python2}
%files
%defattr(644,root,root,755)
%doc CHANGES.md LICENSE.txt README.txt
%dir %{py_sitescriptdir}/reportlab
%dir %{py_sitedir}/reportlab
%{py_sitedir}/reportlab-%{version}-py*.egg-info
%{py_sitedir}/reportlab/*.py[co]
%dir %{py_sitedir}/reportlab/fonts
%{py_sitedir}/reportlab/fonts/00readme.txt
# Dark Garden font (GPL v2+)
%{py_sitedir}/reportlab/fonts/DarkGardenMK.afm
%{py_sitedir}/reportlab/fonts/DarkGardenMK.pfb
%{py_sitedir}/reportlab/fonts/DarkGarden.sfd
%{py_sitedir}/reportlab/fonts/DarkGarden-*.txt
# Bitstream Vera font
%{py_sitedir}/reportlab/fonts/Vera*.ttf
%{py_sitedir}/reportlab/fonts/bitstream-vera-license.txt
# ?
%{py_sitedir}/reportlab/fonts/callig15.afm
%{py_sitedir}/reportlab/fonts/callig15.pfb
# Adobe fonts
%{py_sitedir}/reportlab/fonts/_a*____.pfb
%{py_sitedir}/reportlab/fonts/_e*____.pfb
%{py_sitedir}/reportlab/fonts/co*____.pfb
%{py_sitedir}/reportlab/fonts/sy______.pfb
%{py_sitedir}/reportlab/fonts/z?______.pfb
%dir %{py_sitedir}/reportlab/graphics
%attr(755,root,root) %{py_sitedir}/reportlab/graphics/_renderPM.so
%{py_sitedir}/reportlab/graphics/*.py[co]
%dir %{py_sitedir}/reportlab/graphics/barcode
%{py_sitedir}/reportlab/graphics/barcode/*.py[co]
%dir %{py_sitedir}/reportlab/graphics/charts
%{py_sitedir}/reportlab/graphics/charts/*.py[co]
%dir %{py_sitedir}/reportlab/graphics/widgets
%{py_sitedir}/reportlab/graphics/widgets/*.py[co]
%dir %{py_sitedir}/reportlab/lib
%attr(755,root,root) %{py_sitedir}/reportlab/lib/_rl_accel.so
%attr(755,root,root) %{py_sitedir}/reportlab/lib/pyHnj.so
%{py_sitedir}/reportlab/lib/*.py[co]
%{py_sitedir}/reportlab/lib/hyphen.mashed
%dir %{py_sitedir}/reportlab/pdfbase
%{py_sitedir}/reportlab/pdfbase/*.py[co]
%dir %{py_sitedir}/reportlab/pdfgen
%{py_sitedir}/reportlab/pdfgen/*.py[co]
%dir %{py_sitedir}/reportlab/platypus
%{py_sitedir}/reportlab/platypus/*.py[co]
%endif

%if %{with python3}
%files -n python3-%{module}
%defattr(644,root,root,755)
%doc CHANGES.md LICENSE.txt README.txt
%dir %{py3_sitescriptdir}/reportlab
%dir %{py3_sitedir}/reportlab
%{py3_sitedir}/reportlab-%{version}-py*.egg-info
%{py3_sitedir}/reportlab/*.py
%{py3_sitedir}/reportlab/__pycache__
%dir %{py3_sitedir}/reportlab/fonts
%{py3_sitedir}/reportlab/fonts/00readme.txt
# Dark Garden font (GPL v2+)
%{py3_sitedir}/reportlab/fonts/DarkGardenMK.afm
%{py3_sitedir}/reportlab/fonts/DarkGardenMK.pfb
%{py3_sitedir}/reportlab/fonts/DarkGarden.sfd
%{py3_sitedir}/reportlab/fonts/DarkGarden-*.txt
# Bitstream Vera font
%{py3_sitedir}/reportlab/fonts/Vera*.ttf
%{py3_sitedir}/reportlab/fonts/bitstream-vera-license.txt
# ?
%{py3_sitedir}/reportlab/fonts/callig15.afm
%{py3_sitedir}/reportlab/fonts/callig15.pfb
# Adobe fonts
%{py3_sitedir}/reportlab/fonts/_a*____.pfb
%{py3_sitedir}/reportlab/fonts/_e*____.pfb
%{py3_sitedir}/reportlab/fonts/co*____.pfb
%{py3_sitedir}/reportlab/fonts/sy______.pfb
%{py3_sitedir}/reportlab/fonts/z?______.pfb
%dir %{py3_sitedir}/reportlab/graphics
%attr(755,root,root) %{py3_sitedir}/reportlab/graphics/_renderPM.cpython-*.so
%{py3_sitedir}/reportlab/graphics/*.py
%{py3_sitedir}/reportlab/graphics/__pycache__
%dir %{py3_sitedir}/reportlab/graphics/barcode
%{py3_sitedir}/reportlab/graphics/barcode/*.py
%{py3_sitedir}/reportlab/graphics/barcode/__pycache__
%dir %{py3_sitedir}/reportlab/graphics/charts
%{py3_sitedir}/reportlab/graphics/charts/*.py
%{py3_sitedir}/reportlab/graphics/charts/__pycache__
%dir %{py3_sitedir}/reportlab/graphics/widgets
%{py3_sitedir}/reportlab/graphics/widgets/*.py
%{py3_sitedir}/reportlab/graphics/widgets/__pycache__
%dir %{py3_sitedir}/reportlab/lib
%attr(755,root,root) %{py3_sitedir}/reportlab/lib/_rl_accel.cpython-*.so
%{py3_sitedir}/reportlab/lib/*.py
%{py3_sitedir}/reportlab/lib/__pycache__
%dir %{py3_sitedir}/reportlab/pdfbase
%{py3_sitedir}/reportlab/pdfbase/*.py
%{py3_sitedir}/reportlab/pdfbase/__pycache__
%dir %{py3_sitedir}/reportlab/pdfgen
%{py3_sitedir}/reportlab/pdfgen/*.py
%{py3_sitedir}/reportlab/pdfgen/__pycache__
%dir %{py3_sitedir}/reportlab/platypus
%{py3_sitedir}/reportlab/platypus/*.py
%{py3_sitedir}/reportlab/platypus/__pycache__
%endif

%if %{with doc}
%files apidocs
%defattr(644,root,root,755)
%doc docs/reportlab-userguide.pdf
%endif

%files examples
%defattr(644,root,root,755)
%dir %{_examplesdir}/%{name}-%{version}
%{_examplesdir}/%{name}-%{version}/demos
%changelog
* Tue Mar 25 2025 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/python-ReportLab.git;a=log;h=master

* Tue Mar 25 2025 Jan Rękorajski <baggins@pld-linux.org> 406f1e6
- Release 9 (by relup.sh)

* Mon Mar 17 2025 Jakub Bogusz <qboosh@pld-linux.org> e360c8f
- disable python3 here; release 8

* Sun Mar 16 2025 Jakub Bogusz <qboosh@pld-linux.org> d5cf5c7
- added types patch (fixes python2 build with current gcc)

* Sun Mar 16 2025 Jakub Bogusz <qboosh@pld-linux.org> fe73ba9
- removed obsolete setup patch (dropped in 2.3-1)

* Tue Mar 11 2025 Jan Rękorajski <baggins@pld-linux.org> f7a4b48
- doc/test rebuild for python 3.13

* Mon Mar 10 2025 Jan Rękorajski <baggins@pld-linux.org> ccf7c62
- python 3.13 rebuild

* Sat Sep 10 2022 Jakub Bogusz <qboosh@pld-linux.org> 245a5fc
- python2 note

* Wed Mar 30 2022 Jan Rękorajski <baggins@pld-linux.org> 429a57d
- rebuild with tests and docs

* Sat Mar 26 2022 Jan Rękorajski <baggins@pld-linux.org> 2460c6a
- Release 4 (by relup.sh)

* Sat Mar 26 2022 Jan Rękorajski <baggins@pld-linux.org> 5c15d38
- rebuild with python 3.10

* Fri Mar 25 2022 Jan Rękorajski <baggins@pld-linux.org> f47c38d
- rebuild with python 3.10

* Thu Mar 17 2022 Jakub Bogusz <qboosh@pld-linux.org> 10f52c4
- updated to 3.5.68

* Sat Nov 20 2021 Jan Rękorajski <baggins@pld-linux.org> aaeb716
- rebuild with separate debuginfo build-ids

* Mon Mar 01 2021 Jan Rękorajski <baggins@pld-linux.org> e972138
- up to 3.5.59

* Sun Feb 28 2021 Jan Rękorajski <baggins@pld-linux.org> f85c02f
- unconditional noarch subpackages

* Fri Feb 26 2021 Jan Rękorajski <baggins@pld-linux.org> 5f4ea2a
- release 2 (by relup.sh)

* Sat Mar 07 2020 Jakub Bogusz <qboosh@pld-linux.org> f1821ff
- updated to 3.5.34
- added python3 modules

* Fri May 20 2016 Mateusz Korniak <matkor@pld-linux.org> 8bc38ff
- Version 3.3.0

* Mon Nov 30 2015 Jacek Konieczny <j.konieczny@eggsoft.pl> acc826e
- release 4 (by relup.sh)

* Sun Nov 29 2015 Jacek Konieczny <jajcus@jajcus.net> 9771801
- BR: rpmbuild(macros) >= 1.710

